# landau.py

A library to calculate thermodynamic equilibria and plot phase diagrams in the
(semi-)grand ensemble.


## Building packages

```bash
pip install build
python -m build --sdist
```

## Citation

This code is part of a [publication](https://doi.org/10.21203/rs.3.rs-4732459/v1), please cite it accordingly if you use this package in your work

```
@article{poul2024automated,
  title={Automated Generation of Structure Datasets for Machine Learning Potentials and Alloys},
  author={Poul, Marvin and Huber, Liam and Neugebauer, J{\"o}rg},
  year={2024}
}
```
